==> verticalpodautoscaler-model-v1-6.4.0-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/PodUpdatePolicyFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodUpdatePolicyFluentImpl<A extends PodUpdatePolicyFluent<A>> extends BaseFluent<A> implements PodUpdatePolicyFluent<A>{
  public PodUpdatePolicyFluentImpl() {
  }
  public PodUpdatePolicyFluentImpl(PodUpdatePolicy instance) {
    this.withUpdateMode(instance.getUpdateMode()); 
  }
  private String updateMode;
  public String getUpdateMode() {
    return this.updateMode;
  }
  public A withUpdateMode(String updateMode) {
    this.updateMode=updateMode; return (A) this;
  }
  public Boolean hasUpdateMode() {
    return this.updateMode != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodUpdatePolicyFluentImpl that = (PodUpdatePolicyFluentImpl) o;
    if (updateMode != null ? !updateMode.equals(that.updateMode) :that.updateMode != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(updateMode,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (updateMode != null) { sb.append("updateMode:"); sb.append(updateMode); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> verticalpodautoscaler-model-v1-6.7.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/PodUpdatePolicyFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodUpdatePolicyFluentImpl<A extends PodUpdatePolicyFluent<A>> extends BaseFluent<A> implements PodUpdatePolicyFluent<A>{
  public PodUpdatePolicyFluentImpl() {
  }
  public PodUpdatePolicyFluentImpl(PodUpdatePolicy instance) {
    if (instance != null) {
      this.withUpdateMode(instance.getUpdateMode());
    }
  }
  private String updateMode;
  public String getUpdateMode() {
    return this.updateMode;
  }
  public A withUpdateMode(String updateMode) {
    this.updateMode=updateMode; return (A) this;
  }
  public Boolean hasUpdateMode() {
    return this.updateMode != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodUpdatePolicyFluentImpl that = (PodUpdatePolicyFluentImpl) o;
    if (!java.util.Objects.equals(updateMode, that.updateMode)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(updateMode,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (updateMode != null) { sb.append("updateMode:"); sb.append(updateMode); }
    sb.append("}");
    return sb.toString();
  }
  
}
